# Generated by Django 3.2 on 2021-04-18 11:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("doma", "0002_alter_document_file"),
    ]

    operations = [
        migrations.AlterField(
            model_name="document",
            name="preview",
            field=models.ImageField(blank=True, null=True, upload_to="preview/"),
        ),
    ]
