# Generated by Django 3.2 on 2021-04-18 10:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("doma", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="document",
            name="file",
            field=models.FileField(blank=True, upload_to="documents/"),
        ),
    ]
