# Generated by Django 3.2 on 2021-04-18 14:43

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("doma", "0003_alter_document_preview"),
    ]

    operations = [
        migrations.AlterField(
            model_name="document",
            name="replaces",
            field=models.OneToOneField(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="replaced_by",
                to="doma.document",
            ),
        ),
    ]
